@@ -1,5 +1,5 @@
 /// Return the minimum of two values
-#[inline]
+#[inline(always)]
 pub(crate) fn min(v0: f64, v1: f64) -> f64 {
     if v0 < v1 {
         v0
@@ -9,7 +9,7 @@ pub(crate) fn min(v0: f64, v1: f64) -> f64 {
 }
 
 /// Return the maximum of two values
-#[inline]
+#[inline(always)]
 pub(crate) fn max(v0: f64, v1: f64) -> f64 {
     if v0 > v1 {
         v0
